package com.bpcl.lpg.core.service.impl;

import org.slf4j.LoggerFactory;
import com.bpcl.core.util.BPCLDateUtils;
import org.apache.commons.lang3.StringUtils;
import java.util.Date;
import com.bpcl.lpg.core.enums.GenericStatusEnum;
import com.bpcl.lpg.core.model.CODRefillsModel;
import com.bpcl.lpg.core.pojo.RspResponseData;
import com.bpcl.core.customer.service.BpclCustomerService;
import de.hybris.platform.servicelayer.model.ModelService;
import org.slf4j.Logger;
import com.bpcl.lpg.core.service.CodRefillBookingService;

public class CodRefillBookingServiceImpl implements CodRefillBookingService
{
    private static final Logger LOG;
    private ModelService modelService;
    private BpclCustomerService bpclCustomerService;
    
    public void createCODRefill(final RspResponseData rspResponseData, final String contactNumber, final Double amount) {
        final CODRefillsModel codRefillBookingModel = (CODRefillsModel)this.modelService.create((Class)CODRefillsModel.class);
        codRefillBookingModel.setConsumerId(rspResponseData.getConsumerId());
        codRefillBookingModel.setOrderNo(rspResponseData.getOrderNo());
        codRefillBookingModel.setStatus(this.getStatus(rspResponseData.getReturnCode()));
        codRefillBookingModel.setDescription(rspResponseData.getReturnMsg());
        codRefillBookingModel.setQuantity(Integer.valueOf(Integer.parseInt(rspResponseData.getProductQty())));
        codRefillBookingModel.setBpclReferenceId(rspResponseData.getBpclReferenceId());
        codRefillBookingModel.setProductCode(rspResponseData.getProductType());
        codRefillBookingModel.setDistCode(rspResponseData.getDistCode());
        codRefillBookingModel.setBookDate(this.getBookingDate(rspResponseData));
        codRefillBookingModel.setAmount(amount);
        codRefillBookingModel.setAccount(this.bpclCustomerService.getLPGConnectionForCurrentCustomer());
        this.modelService.save((Object)codRefillBookingModel);
    }
    
    private GenericStatusEnum getStatus(final String returnCode) {
        return "200".equals(returnCode) ? GenericStatusEnum.SUCCESS : GenericStatusEnum.FAILED;
    }
    
    private Date getBookingDate(final RspResponseData rspResponseData) {
        final String bookingDate = rspResponseData.getBookDate();
        if (StringUtils.equalsIgnoreCase(rspResponseData.getReturnCode(), "200")) {
            return BPCLDateUtils.getDateAsSpecifiedFormat(bookingDate, "MMM dd yyyy hh:mma");
        }
        if (StringUtils.equalsIgnoreCase(rspResponseData.getReturnCode(), "201")) {
            return BPCLDateUtils.getDateAsSpecifiedFormat(bookingDate, "yyyy-MM-dd hh:mm:ss.sss");
        }
        return null;
    }
    
    public ModelService getModelService() {
        return this.modelService;
    }
    
    public void setModelService(final ModelService modelService) {
        this.modelService = modelService;
    }
    
    public void setBpclCustomerService(final BpclCustomerService bpclCustomerService) {
        this.bpclCustomerService = bpclCustomerService;
    }
    
    static {
        LOG = LoggerFactory.getLogger(CodRefillBookingServiceImpl.class);
    }
}
